@@ -6,14 +6,11 @@ from captcha.widgets import ReCaptchaV2Checkbox
 from tempus_dominus.widgets import DatePicker, TimePicker, DateTimePicker
 
 from django_form_generator.settings import form_generator_settings as fg_settings
-from django_form_generator.models import Field, Form, Option
+from django_form_generator.models import Field, Form, Option, FieldValidator
+from django_form_generator.fields import MultiInputWidgetField, MultiInputField, CustomeSelectFormField
 from django_form_generator import const
 
 
-class CustomeSelectFormField(forms.Select):
-    option_inherits_attrs = True
-
-
 class FormGeneratorBaseForm(forms.Form):
     def __init__(self, form, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -31,7 +28,8 @@ class FormGeneratorBaseForm(forms.Form):
     def _handel_required_fields(self, field, form_field):
         if self.data and field.content_object:
             if isinstance(field.content_object, Option):
-                field_name = self.instance.get_fields(extra={"id__in":field.content_object.fields.values_list('id', flat=True)}).last().name
+                field_name = self.instance.get_fields(extra={"id__in":
+                                                field.content_object.fields.values_list('id', flat=True)}).last().name
                 parent_data = self.data.get(field_name, '')
                 if str(field.object_id) not in parent_data:
                     form_field.required = False
@@ -53,6 +51,15 @@ class FormGeneratorBaseForm(forms.Form):
         )
         return forms.CharField(**field_attrs)
 
+    def prepare_multi_text_input(self, form: Form, field: Field):
+        widget_attrs: dict = field.build_widget_attrs(
+            form, {"content_type": "field", "multi-input": True}
+        )
+        field_attrs: dict = field.build_field_attrs(
+            {"widget": MultiInputWidgetField(attrs=widget_attrs)}
+        )
+        return MultiInputField(**field_attrs)
+
     def prepare_text_area(self, form: Form, field: Field):
         widget_attrs: dict = field.build_widget_attrs(
             form, {"content_type": "field"}
@@ -127,7 +134,7 @@ class FormGeneratorBaseForm(forms.Form):
 
     def prepare_dropdown(self, form: Form, field: Field):
         widget_attrs: dict = field.build_widget_attrs(
-            form, {"content_type": "value"}
+            form, {"content_type": "option"}
         )
         choices = field.get_choices().values_list("id", "name")
         field_attrs: dict = field.build_field_attrs(
@@ -140,7 +147,7 @@ class FormGeneratorBaseForm(forms.Form):
 
     def prepare_multi_checkbox(self, form: Form, field: Field):
         widget_attrs: dict = field.build_widget_attrs(
-            form, {"content_type": "value"}
+            form, {"content_type": "option"}
         )
         choices = field.get_choices().values_list("id", "name")
         field_attrs: dict = field.build_field_attrs(
@@ -153,7 +160,7 @@ class FormGeneratorBaseForm(forms.Form):
 
     def prepare_radio(self, form: Form, field: Field):
         widget_attrs: dict = field.build_widget_attrs(
-            form, {"content_type": "value"}
+            form, {"content_type": "option"}
         )
         choices = field.get_choices().values_list("id", "name")
         field_attrs: dict = field.build_field_attrs(
@@ -212,17 +219,17 @@ class FormGeneratorResponseForm(FormGeneratorBaseForm):
 
     def _initial_fields(self):
         form_response_data = self.form_response.get_data()
-        for i, field in enumerate(self.instance.get_fields()):
+        for i, field in enumerate(self.form_response.form.get_fields()):
             field_name = field.name
             method = f"prepare_{field.genre}"
             if hasattr(self, method):
                 self.fields[field_name] = getattr(self, method)(self.instance, field)
-                if not self.instance.is_editable:
-                    self.fields[field_name].widget.attrs.update({"disabled": True})
                 try:
                     initial_value = form_response_data[i].get(
                         "value", None
                     )
+                    if (not initial_value and isinstance(initial_value, (list, tuple))) or field.write_only:
+                        initial_value = None
                     self.fields[field_name].initial = initial_value
                     if initial_value:
                         try:
@@ -232,6 +239,9 @@ class FormGeneratorResponseForm(FormGeneratorBaseForm):
                 except IndexError:
                     pass
                 
+                if not self.instance.is_editable:
+                    self.fields[field_name].widget.attrs.update({"disabled": True})
+                
                 self._handel_required_fields(field, self.fields[field.name])
 
     def save(self):
@@ -252,7 +262,7 @@ class FieldForm(forms.ModelForm):
 
     def clean(self):
         cleaned_data = super().clean()
-        if cleaned_data["genre"] == const.FieldGenre.UPLOAD_FILE:
+        if 'genre' in cleaned_data and cleaned_data["genre"] == const.FieldGenre.UPLOAD_FILE:
             data = [val for key, val in self.data.items() if key.startswith('validators') and key.endswith('validator') and val]
             if const.Validator.FILE_EXTENTION.value not in data or const.Validator.FILE_SIZE.value not in data:
                 raise forms.ValidationError(
@@ -268,6 +278,17 @@ class FormAdminForm(forms.ModelForm):
         fields = "__all__"
 
 
+class ValidatorAdminForm(forms.ModelForm):
+
+    class Meta:
+        model = FieldValidator
+        fields = '__all__'
+
+    def clean_value(self):
+        value = self.cleaned_data['value']
+        if value:
+            const.Validator(self.cleaned_data['validator']).clean(value)
+        return value
 
 class FormResponseFilterForm(forms.Form):
     operand = forms.ChoiceField(choices=(('OR', 'OR'), ('AND', 'AND')),  required=False)
